module MemberAccessor
  def self.included(base)
    base.class_eval do
      has_many :identities, dependent: :destroy, primary_key: :email, foreign_key: :email
      has_one :member_profile, dependent: :destroy
      alias_method :profile, :member_profile
      has_one :investor_account, dependent: :destroy
      alias_method :investor, :investor_account
      has_one :preference, dependent: :destroy
      has_many :session_analytics, dependent: :destroy
    end
  end

  def age
    TimeDifference.between(date_of_birth, Date.today).in_years.to_i if date_of_birth.present?
  end

  def investments
    investor_account && investor_account.investments
  end

  def is_investor?
    investor.present? and investor.approval_status != ::InvestorConstants::STATUS_NON_INVESTOR
  end

  def is_approved_investor?
    is_investor? && investor.approval_status == ::InvestorConstants::STATUS_APPROVED
  end
end