class InvestorTierForm
  include ActiveModel::Model
  include Virtus.model

  attr_accessor :member, :investor_account
  attribute :model_id, Integer


  class << self
    def find(id)
      member = Member.find id
      form = self.new member.attributes.merge(member.investor_account && member.investor_account.attributes || {})
      form.set_model id
      return form
    end

    def update(params)
      if params[:model_id].blank?
        raise 'Model ID not found'
      end
      form = self.new sanitized_params(params)
      form.set_model params[:model_id]
      form.persist(params)
      return form
    end

    def sanitized_params(params)
      return params
    end
  end

  def set_model(member_id)
    @model_id = (member_id.respond_to? :id)? member_id.id : member_id
    @member = Member.find member_id
    @investor_account = @member.investor.blank?? InvestorAccount.create!(member: @member) : @member.investor
  end

  def persist(params)
    params.each do |k,v|
      setter_method = "#{k}="
      if @member.respond_to? setter_method
        @member.send setter_method, v
      end
      if @investor_account.respond_to? setter_method
        @investor_account.send setter_method, v
      end
    end
    @member.save!
    @investor_account.save!
  end

  module Validator
    extend ActiveSupport::Concern

    included do
    end

  end
  include Validator
end