module InvestorAccountStateMachine
  def self.included(base)
    base.include InvestorAccountLifecycle::StateMachineTransitionMixin
    base.class_eval do
      state_machine :approval_status, initial: :non_investor do
        audit_trail class: base.investor_state_transition_klass
        event :application_submitted do
          transition :non_investor => :pending_verification
        end

        event :application_resubmitted do
          transition :declined => :pending_verification
        end

        event :application_screened do
          transition :pending_verification => :screened
        end

        event :application_approved do
          transition :screened => :approved
        end

        event :application_declined do
          transition [:pending_verification, :screened] => :declined
        end

        after_transition on: :application_submitted, do: :callback_submission
        after_transition on: [:application_submitted, :application_resubmitted], do: :callback_submission
        after_transition on: :application_approved, do: :callback_application_approved
        after_transition on: :application_declined, do: :callback_application_declined
      end
    end
  end
end