module NexusCore
  module ReportUtils
    module DateDefinition
      def this_week
        Date.today.strftime('%Y%W')
      end

      def last_week
        Date.today.last_week.strftime('%Y%W')
      end

      def end_of_last_week
        Date.today.last_week.end_of_week
      end

      def end_of_last_month
        Date.today.last_month.end_of_month
      end

      def starting_last_month
        Date.today.last_month.beginning_of_month
      end
    end
    extend DateDefinition

    module PeriodDefinition
      def last_week_period
        full_weeks_in_period(Date.today.last_week, Date.today)
      end

      def last_month_period
        full_weeks_in_period(Date.today.last_month, Date.today)
      end

      def full_weeks_in_period(start, till)
        start = Date.today.last_week.beginning_of_week if start.blank?
        till = Date.today.last_week.end_of_week if till.blank?
        start = [Date.today.last_week.beginning_of_week, start.beginning_of_week].min
        till = [Date.today.last_week.end_of_week, till.end_of_week].min
        [start, till].sort {|a,b| a <=> b}
      end
    end
    extend PeriodDefinition

    module PercentageHelper
      def to_percentage(num)
        "#{to_percentage_number(num)}%"
      end

      def to_percentage_number(num)
        (num * 100).round(2)
      end
    end
    extend PercentageHelper

    def self.decode_ip(ip_addr)
      g = GeoIP.new(NexusCore::GEOIP_DAT_LOCATION)
      begin
        country = g.country(ip_addr).country_name
      rescue
        country = 'N/A'
        puts "Unable to Reverse Geocode: '#{ip_addr}'"
      end
      return country
    end
  end
end